.. _global_todo:

Long-term todo list
======================================================================

.. todo::
    * Store mean fitness in population objects.
    * Multi-locus pop-gen simulations
    * Enable stateful fitness model updating for multi-locus simulations [`Done for qtrait sims <https://github.com/molpopgen/fwdpy11/commit/161dfcef63f3abf28ad56df33b84a92d87d7750f>`_]
    * More extensive unit testing of fwdpy11.model_params
    * Support for evolution of multiple populations with migration
    * Support for tracking parents and geographic location
